@@ -49,11 +49,15 @@ void  chum_set_selected_language(const gchar* language){
 }
 
 
-gboolean duetto=TRUE;
+static gboolean duetto=TRUE;
 void chum_set_duetto(gboolean b){
 	duetto=b;
 }
 
+gboolean chum_get_duetto(){
+	return duetto;
+}
+
 
 //FALSE means advanced_game
 static gboolean chum_easy_game = TRUE;
