@@ -10,6 +10,7 @@
 
 #include "jammo-mentor.h"
 #include "../meam/jammo-sample.h"
+#include <time.h>
 
 G_DEFINE_TYPE(JammoMentor, jammo_mentor, TANGLE_TYPE_BUTTON);
 
@@ -28,9 +29,13 @@ struct _JammoMentorPrivate {
 	gulong idle_timeout;
 	
 	GList* spoken_speeches;
-	guint idle_timeout_id;
 	ClutterScript* script;
 	JammoSample* active_sample;
+
+	ClutterActor* stage;
+	gulong stage_captured_event_handler_id;
+	guint timeout_event_source_id;
+	time_t last_activity_time;
 };
 
 static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCallback callback, gpointer user_data);
@@ -95,6 +100,12 @@ void jammo_mentor_speak_once_with_callback(JammoMentor* mentor, const gchar* spe
 	}
 }
 
+void jammo_mentor_shut_up(JammoMentor* mentor) {
+	if (mentor->priv->active_sample) {
+		jammo_sample_stop(mentor->priv->active_sample);
+	}
+}
+
 const gchar* jammo_mentor_get_idle_speech(JammoMentor* mentor) {
 
 	return mentor->priv->idle_speech;
@@ -104,6 +115,7 @@ void jammo_mentor_set_idle_speech(JammoMentor* mentor, const gchar* speech) {
 	if (g_strcmp0(mentor->priv->idle_speech, speech)) {
 		g_free(mentor->priv->idle_speech);
 		mentor->priv->idle_speech = g_strdup(speech);
+		set_idle_timeout(mentor, TRUE);
 		g_object_notify(G_OBJECT(mentor), "idle-speech");
 	}
 }
@@ -116,9 +128,7 @@ gulong jammo_mentor_get_idle_timeout(JammoMentor* mentor) {
 void jammo_mentor_set_idle_timeout(JammoMentor* mentor, gulong milliseconds) {
 	if (mentor->priv->idle_timeout != milliseconds) {
 		mentor->priv->idle_timeout = milliseconds;
-		if (!mentor->priv->active_sample) {
-			set_idle_timeout(mentor, TRUE);
-		}
+		set_idle_timeout(mentor, TRUE);
 		g_object_notify(G_OBJECT(mentor), "idle-timeout");
 	}
 }
@@ -190,16 +200,31 @@ static void jammo_mentor_get_property(GObject* object, guint prop_id, GValue* va
         }
 }
 
+static void jammo_mentor_show(ClutterActor* actor) {
+	set_idle_timeout(JAMMO_MENTOR(actor), TRUE);
+	
+	CLUTTER_ACTOR_CLASS(jammo_mentor_parent_class)->show(actor);
+}
+
+static void jammo_mentor_hide(ClutterActor* actor) {
+	set_idle_timeout(JAMMO_MENTOR(actor), FALSE);
+	
+	CLUTTER_ACTOR_CLASS(jammo_mentor_parent_class)->hide(actor);
+}
+
 static void jammo_mentor_finalize(GObject* object) {
 	G_OBJECT_CLASS(jammo_mentor_parent_class)->finalize(object);
 }
 
 static void jammo_mentor_dispose(GObject* object) {
+	set_idle_timeout(JAMMO_MENTOR(object), FALSE);
+
 	G_OBJECT_CLASS(jammo_mentor_parent_class)->dispose(object);
 }
 
 static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	GObjectClass* gobject_class = G_OBJECT_CLASS(mentor_class);
+	ClutterActorClass* clutter_actor_class = CLUTTER_ACTOR_CLASS(mentor_class);
 	TangleButtonClass* button_class = TANGLE_BUTTON_CLASS(mentor_class);
 
 	gobject_class->finalize = jammo_mentor_finalize;
@@ -207,6 +232,9 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	gobject_class->set_property = jammo_mentor_set_property;
 	gobject_class->get_property = jammo_mentor_get_property;
 
+	clutter_actor_class->show = jammo_mentor_show;
+	clutter_actor_class->hide = jammo_mentor_hide;
+
 	button_class->clicked = jammo_mentor_clicked;
 
 	/**
@@ -245,13 +273,13 @@ static void jammo_mentor_class_init(JammoMentorClass* mentor_class) {
 	/**
 	 * JammoMentor:idle-time:
 	 *
-	 * The time after the mentor will speak (see :idle-speech) if an user has been idle.
+	 * The time in seconds after the mentor will speak (see :idle-speech) if an user has been idle.
 	 * Value 0 means disabled.
 	 */
 	g_object_class_install_property(gobject_class, PROP_IDLE_TIMEOUT,
 	                                g_param_spec_ulong("idle-timeout",
 	                                                   "Idle timeout",
-	                                                   "The time after the mentor will speak if an user has been idle.",
+	                                                   "The time in seconds after the mentor will speak if an user has been idle.",
 	                                                   0, G_MAXULONG, 0,
 	                                                   G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_CONSTRUCT));
 
@@ -278,6 +306,8 @@ static void on_sample_stopped(JammoSample* sample, gpointer user_data) {
 	mentor->priv->active_sample = NULL;
 
 	tangle_actor_animate(TANGLE_ACTOR(mentor), CLUTTER_EASE_IN_QUAD, 1500, "scale-x", mentor->priv->standby_scale, "scale-y", mentor->priv->standby_scale, NULL);
+
+	set_idle_timeout(mentor, TRUE);
 	
 	if (callback) {
 		callback(mentor, speech, data);
@@ -288,6 +318,9 @@ static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCal
 	gchar* filename;
 	TangleVault* vault;
 	
+	set_idle_timeout(mentor, FALSE);
+	tangle_actor_show(TANGLE_ACTOR(mentor));
+	
 	if (mentor->priv->active_sample) {
 		jammo_sample_stop(mentor->priv->active_sample);
 	}
@@ -307,6 +340,48 @@ static void speak(JammoMentor* mentor, const gchar* speech, JammoMentorSpokenCal
 	jammo_sample_play(mentor->priv->active_sample);
 }
 
+static gboolean on_stage_captured_event(ClutterActor* actor, ClutterEvent* event, gpointer user_data) {
+	JammoMentor* mentor;
+	
+	mentor = JAMMO_MENTOR(user_data);
+	
+	mentor->priv->last_activity_time = time(NULL);
+	
+	return FALSE;
+}
+
+static gboolean on_timeout(gpointer user_data) {
+	JammoMentor* mentor;
+	time_t elapsed_time;
+	
+	mentor = JAMMO_MENTOR(user_data);
+	
+	elapsed_time = time(NULL) - mentor->priv->last_activity_time;
+	if (elapsed_time >= mentor->priv->idle_timeout) {
+		speak(mentor, mentor->priv->idle_speech, NULL, NULL);
+	} else {
+		mentor->priv->timeout_event_source_id = g_timeout_add((mentor->priv->idle_timeout - elapsed_time) * 1000, on_timeout, mentor);
+	}
+	
+	return FALSE;
+}
+
 static void set_idle_timeout(JammoMentor* mentor, gboolean activate) {
-	/* TODO */
+	if (mentor->priv->timeout_event_source_id) {
+		g_source_remove(mentor->priv->timeout_event_source_id);
+		mentor->priv->timeout_event_source_id = 0;
+	}
+	
+	if (activate && mentor->priv->idle_timeout && mentor->priv->idle_speech && !mentor->priv->active_sample && CLUTTER_ACTOR_IS_VISIBLE(mentor)) {
+		if (!mentor->priv->stage && (mentor->priv->stage = clutter_actor_get_stage(CLUTTER_ACTOR(mentor)))) {
+			mentor->priv->stage_captured_event_handler_id = g_signal_connect(mentor->priv->stage, "captured-event", G_CALLBACK(on_stage_captured_event), mentor);
+		}
+
+		mentor->priv->last_activity_time = time(NULL);
+
+		mentor->priv->timeout_event_source_id = g_timeout_add(mentor->priv->idle_timeout * 1000, on_timeout, mentor);
+	} else if (!activate && mentor->priv->stage) {
+		g_signal_handler_disconnect(mentor->priv->stage, mentor->priv->stage_captured_event_handler_id);
+		mentor->priv->stage = NULL;
+	}
 }
