@@ -100,9 +100,9 @@ static void on_pitch_detected(JammoRecordingTrack* track, gfloat frequency, gpoi
 
 
 
-gboolean singingame_start_sequencer(){
+static void singingame_start_sequencer(JammoMentor* mentor, const gchar* speech, gpointer user_data){
+tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
 chum_play_sequencer();
-return FALSE;
 }
 
 
@@ -113,7 +113,7 @@ static void song_view_showed(TangleActor *actor, ClutterActorBox *arg1, ClutterA
 	filepath1 =  g_strdup_printf("/opt/jammo/mentor_speech/mentor_song_%s_fi.ogg", chum_get_current_song());
 	printf("pass to mentor: '%s' \n",filepath1);
 
-	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), filepath1, chum_play_sequencer, NULL);
+	jammo_mentor_speak_with_callback(jammo_mentor_get_default(), filepath1, singingame_start_sequencer, NULL);
 	jammo_mentor_set_idle_speech(jammo_mentor_get_default(), "");
 }
 
@@ -196,7 +196,6 @@ void singinggame_song_click(TangleAction *action, GObject *source, const gchar *
 	#endif /*OFFICIAL_RELEASE */
 	
 	g_free(filepath1);
-
 }
 
 void singinggame_cross_click(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
@@ -221,12 +220,13 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 
 
 		chum_play_recorded_and_backing_track(); 
-		jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_welldone_fi.ogg", chum_play_sequencer, NULL);
+		jammo_mentor_speak_with_callback(jammo_mentor_get_default(), "/opt/jammo/mentor_speech/mentor_welldone_fi.ogg", singingame_start_sequencer, NULL);
 		}
 
 	else if (chum_get_state_of_chum()==SCREEN_PLAY_RECORDED	)
 		{
 		printf("chum_get_state_of_chum()==SCREEN_PLAY_RECORDED");
+		jammo_mentor_shut_up(jammo_mentor_get_default());
 		chum_stop_sequencer();
 
 		//'actor' is pressed button, and it's parent is song-*-view
@@ -238,25 +238,103 @@ void singinggame_cross_click(TangleAction *action, GObject *source, const gchar
 		ClutterActor* view = jammo_get_actor_by_id("songselection-view");
 		clutter_actor_show(view);
 
-		//Automatic saving on N900. THIS MUST BE DOCUMENTED.
-		//filenames look like this: jammo_2010.02.22_21.16.27.wav
-		#ifdef N900
-		gchar* cmd;
-		cmd = g_strdup_printf("cp %s /home/user/MyDocs/jammo_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav", RECORDING_FILENAME );
+		//And show mentor again
+		tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
 
+		//Automatic saving. THIS MUST BE DOCUMENTED.
+		//filenames look like this: jammo_2010.02.22_21.16.27.wav
+		//Saving to cupboard and to log.
+		gchar* cmd;
+		#ifdef N900
+		cmd = g_strdup_printf("cp %s /home/user/MyDocs/jammo/singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav", RECORDING_FILENAME );
+		#else
+		cmd = g_strdup_printf("cp %s /tmp/jammo/singing_`date +%%Y.%%m.%%d_%%H.%%M.%%S`.wav", RECORDING_FILENAME );
+		#endif
+		
 		int error_code = system(cmd);
 		if (error_code)
 			printf("Error, can't call '%s'\n",cmd);
+		
+		#ifdef N900
+		cmd = g_strdup_printf("cp %s /home/user/MyDocs/jammo/singings/%s.wav", RECORDING_FILENAME,chum_get_current_song() );
+		#else
+		cmd = g_strdup_printf("cp %s /tmp/jammo/singings/%s.wav", RECORDING_FILENAME,chum_get_current_song() );
 		#endif
+		
+		error_code = system(cmd);
+		if (error_code)
+			printf("Error, can't call '%s'\n",cmd);
+		
+		g_free(cmd);
 		}
-
+		
 	else printf("Singinggame_cross_click: Error\n");
 
 }
 
 
+static void do_hiding_and_dimming(){
+	//Add transperency to songs which do not have current language vocal-track.
+	//Hide advanced songs, when game level is easy.
+	///////////////////////////////////////////////////////////////////////////////
+	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
+	char* selected_language = chum_get_selected_language();
+	GList* songlist = clutter_container_get_children(CLUTTER_CONTAINER(container));
+	GList *l;
 
 
+	songlist = clutter_container_get_children(CLUTTER_CONTAINER(container));
+	for (l = songlist; l; l = l->next){
+		const gchar* id_of_actor;
+		id_of_actor = clutter_get_script_id(G_OBJECT(l->data));
+		if (id_of_actor==NULL) continue; //In child-list there are many id=NULL actors.
+			
+		if (strncmp(id_of_actor,"songselection-song-",19)==0)
+			{
+			const gchar* name;
+			g_object_get(l->data, "name", &name, NULL);
+			//printf("name of song: '%s'\n",name);
+			
+			ClutterActor* button;
+			ClutterActor* texture;
+			button = l->data;
+			texture = tangle_button_get_normal_background_actor( TANGLE_BUTTON(button));
+
+
+			gchar* filename;
+			filename = g_strdup_printf("%s/songs/%s/vocal%s.ogg",DATA_DIR,name,selected_language);
+			//printf("filename: '%s'\n",filename);
+			int fd = open(filename,O_RDONLY);
+			if (fd == -1  && chum_get_duetto() ) //File not found => no vocal_track for this language
+				{
+				//printf(" dim this\n");
+				clutter_actor_set_opacity(texture,64); //0=transparency, 255=opaque
+				}
+			else
+				{
+				clutter_actor_set_opacity(texture,255); //0=transparency, 255=opaque
+				}
+				
+				//Stupid way to mark these songs to advanced game, FIXME
+				if (chum_is_easy_game() &&
+						(strncmp(id_of_actor,"songselection-song-miska",24)==0 ||
+						strncmp(id_of_actor,"songselection-song-pig",22)==0 ||
+						strncmp(id_of_actor,"songselection-song-avignon",26)==0)  )
+					{
+					//printf("  hide this\n");
+					clutter_actor_hide(button);
+					}
+				else
+					{
+					//printf("  show this\n");
+					clutter_actor_show(button);
+					}
+					
+			}
+	}
+	
+	g_list_free(songlist);
+}
 
 void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	ClutterActor* ct =CLUTTER_ACTOR(source);
@@ -282,68 +360,11 @@ void singinggame_duetto_clicked(TangleAction *action, GObject *source, const gch
 	button = jammo_get_actor_by_id("songselection-duetto");
 	texture = jammo_get_actor_by_id(new_name);
 	tangle_button_set_normal_background_actor(TANGLE_BUTTON(button), texture);
-}
-
-
-ClutterColor white_color = { 0, 0, 0, 0xbb };
-ClutterColor *get_white_color(){        return &white_color; }
-
-static void do_hiding_boxes(){
-	//Add transperency mask to songs which do not have current language vocal-track.
-	///////////////////////////////////////////////////////////////////////////////
-	ClutterActor* container = jammo_get_actor_by_id("songselection-all-songs");
-	char* selected_language = chum_get_selected_language();
-	gfloat x,y,w,h;
-	ClutterActor* box;
-	GList* songlist = clutter_container_get_children(CLUTTER_CONTAINER(container));
-	GList *l;
-
-	//First: Remove all existing mask-boxes.
-	for (l = songlist; l; l = l->next){
-		const gchar* name;
-		g_object_get(l->data, "name", &name, NULL);
-		if (name!=NULL && strncmp(name,"box",3)==0)
-			{
-			//clutter_actor_hide(l->data);
-			clutter_container_remove_actor(CLUTTER_CONTAINER(container), CLUTTER_ACTOR(l->data));
-			}
-	}
-	g_list_free(songlist);
-
-	//Second: add new boxes
-	songlist = clutter_container_get_children(CLUTTER_CONTAINER(container));
-	for (l = songlist; l; l = l->next){
-		const gchar* id_of_actor;
-		id_of_actor = clutter_get_script_id(G_OBJECT(l->data));
-		if (id_of_actor==NULL) continue; //In child-list there are many id=NULL actors.
-			
-		if (strncmp(id_of_actor,"songselection-song-",19)==0)
-			{
-			const gchar* name;
-			g_object_get(l->data, "name", &name, NULL);
-		  //printf("name: '%s'\n",name);
-			
-			gchar* filename;
-			filename = g_strdup_printf("%s/songs/%s/vocal%s.ogg",DATA_DIR,name,selected_language);
-			//printf("filename: '%s'\n",filename);
-			int fd = open(filename,O_RDONLY);
-			if (fd == -1) //File not found => now vocal_track for this language
-				{
-				g_object_get(l->data, "x", &x, "y", &y, "width", &w, "height", &h, NULL);
-				//printf("child: %s, %lf: %lf: %lf: %lf\n",id_of_actor,x,y,w,h);
-				box=clutter_rectangle_new_with_color (get_white_color());
-				clutter_actor_set_size (box, w,h);
-				clutter_actor_set_position (box, x, y); 
-				clutter_actor_show (box);
-				clutter_actor_set_name (box, "box"); //this is used to remove this b
-				clutter_container_add_actor (CLUTTER_CONTAINER (container), box);
-				}
-			}
-	}
 	
-	g_list_free(songlist);
+	do_hiding_and_dimming();
 }
 
+
 void singingame_show_songselection(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 		ClutterActor* view;
 		if ((view = jammo_get_actor_by_id("songselection-view"))) {
@@ -353,7 +374,7 @@ void singingame_show_songselection(TangleAction *action, GObject *source, const
 		if ((view = jammo_get_actor_by_id("main-menu-view"))) {
 			clutter_actor_hide(view);
 		}
-		do_hiding_boxes();
+		do_hiding_and_dimming();
 }
 
 
@@ -386,7 +407,7 @@ void singinggame_language_clicked(TangleAction *action, GObject *source, const g
 		clutter_actor_hide(view);
 	}
 
-	do_hiding_boxes();
+	do_hiding_and_dimming();
 }
 
 
