@@ -23,9 +23,9 @@ static gboolean save_composition() {
 
 	//filenames look like this: jammo_comp_2010.02.22_21.16.27.wav TODO
 	#ifdef N900
-	outputFilename = g_strdup_printf("/home/user/MyDocs/jammo_comp.wav");
+	outputFilename = g_strdup_printf("/home/user/MyDocs/jammo/compositions/jammo_comp");
 	#else
-	outputFilename = g_strdup_printf("/tmp/jammo/jammo_comp");
+	outputFilename = g_strdup_printf("/tmp/jammo/compositions/jammo_comp");
 	#endif
 
 	ofp = fopen(outputFilename, "w");
@@ -62,16 +62,7 @@ static gboolean save_composition() {
 }
 
 
-/*
-This is called when user click 'cross' / 'back_to_theme_selection'
-Give view to hide as parameter.
-
-
-TODO: ASK FOR SAVING. Now it saves automatically.
-*/
-static void back_to_theme_selection_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
-	save_composition();
-
+static void close_themeselection(gpointer data){
 	ClutterActor* new_view;
 	new_view = jammo_get_actor_by_id("themeselection-view");	
 
@@ -83,6 +74,84 @@ static void back_to_theme_selection_clicked (ClutterTexture *actor, ClutterEvent
 	
 }
 
+static gboolean yes_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
+	printf("yes selected\n");
+	save_composition();
+	jammo_mentor_speak(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_save_confirmed_fi.ogg");
+	
+	close_themeselection(data);
+	return FALSE;
+}
+
+static gboolean no_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
+	printf("no selected\n");
+	close_themeselection(data);
+	return FALSE;
+}
+
+
+static gboolean cancel_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
+	printf("cancel selected\n");
+	
+	tangle_actor_destroy_animated(TANGLE_ACTOR(data));
+	return FALSE;
+}
+
+static ClutterColor transparency_color = { 0, 0, 0, 0xdd };
+static ClutterColor *get_transparency_color(){ return &transparency_color; }
+ 
+static void asking_for_saving(ClutterActor* view, gpointer data){
+	jammo_mentor_speak(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg");
+	jammo_mentor_set_idle_speech(jammo_mentor_get_default(),"/opt/jammo/mentor_speech/mentor_ask_for_saving_composing_fi.ogg");
+
+	ClutterActor* container_for_asking = tangle_widget_new(); //TANGLEWIDGET
+
+	ClutterActor* box=clutter_rectangle_new_with_color (get_transparency_color());
+	clutter_actor_set_size (box, 800,480);
+	clutter_actor_set_position (box, 0, 0); 
+	clutter_actor_show (box);
+	clutter_actor_set_reactive(box,TRUE);
+	clutter_container_add_actor (CLUTTER_CONTAINER (container_for_asking), box);
+
+	ClutterActor* no_button;
+	no_button=clutter_texture_new_from_file("/opt/jammo/buttons/no-button.png", NULL);
+	g_object_set(no_button, "x", 303.0,  "y", 60.0, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), no_button, NULL);
+	clutter_actor_set_reactive(no_button,TRUE);
+	g_signal_connect (no_button, "button-press-event", G_CALLBACK (no_clicked),data);
+
+	ClutterActor* yes_button;
+	yes_button=clutter_texture_new_from_file("/opt/jammo/buttons/yes-button.png", NULL);
+	g_object_set(yes_button, "x", 300.0,  "y", 241.0, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), yes_button, NULL);
+	clutter_actor_set_reactive(yes_button,TRUE);
+	g_signal_connect (yes_button, "button-press-event", G_CALLBACK (yes_clicked),data);
+
+	
+	ClutterActor* cancel_button;
+	cancel_button=clutter_texture_new_from_file("/opt/jammo/cross_icon.png", NULL);
+	g_object_set(cancel_button, "x", 719.0,  "y", 16.0, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(container_for_asking), cancel_button, NULL);
+	clutter_actor_set_reactive(cancel_button,TRUE);
+	g_signal_connect (cancel_button, "button-press-event", G_CALLBACK (cancel_clicked),container_for_asking);
+
+	
+	clutter_container_add(CLUTTER_CONTAINER(view),container_for_asking, NULL);
+}
+/*
+This is called when user click 'cross' / 'back_to_theme_selection'
+Give view to hide as parameter.
+
+
+TODO: ASK FOR SAVING. Now it saves automatically.
+*/
+static void back_to_theme_selection_clicked (ClutterTexture *actor, ClutterEvent *event, gpointer data){
+	chum_stop_sequencer();
+	asking_for_saving(CLUTTER_ACTOR(clutter_actor_get_parent(CLUTTER_ACTOR(actor))),data);
+}
+
+
+
 
 
 /*
@@ -127,26 +196,50 @@ static void menu_clicked(ClutterTexture *actor, ClutterEvent *event, gpointer us
 		tangle_actor_show(TANGLE_ACTOR(user_data));
 	}
 }
+static gboolean on_play_button_clicked(ClutterActor* play_button, ClutterEvent *event, gpointer user_data);
+
+static gboolean on_stop_button_clicked(ClutterActor* play_button, ClutterEvent *event, gpointer user_data) {
+	printf("Play button pressed (stop)\n");
+	chum_stop_sequencer();
+	tangle_actor_show(TANGLE_ACTOR(jammo_mentor_get_default()));
+
+	//Change button to play
+	ClutterActor* view = clutter_actor_get_parent(play_button);
+	clutter_actor_destroy(play_button);
+	play_button=clutter_texture_new_from_file("/opt/jammo/buttons/play-button.png", NULL);
+	g_object_set(play_button, "x", 0.0,  "y", 195.0, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(view), play_button, NULL);
+	clutter_actor_set_reactive(play_button,TRUE);
+	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_play_button_clicked),NULL);
 
-static gboolean on_play_button_clicked(ClutterActor* actor2, ClutterEvent *event, gpointer user_data){	
-	printf("Play button pressed\n");
-	chum_play_sequencer();
 	return FALSE;
 }
 
 
-gboolean themeselection_load() {
+static gboolean on_play_button_clicked(ClutterActor* play_button, ClutterEvent *event, gpointer user_data) {
+	printf("Play button pressed (play)\n");
+	tangle_actor_hide_animated(TANGLE_ACTOR(jammo_mentor_get_default()));
+	chum_play_sequencer();
+
+	//Change button to stop
+	ClutterActor* view = clutter_actor_get_parent(play_button);
+	clutter_actor_destroy(play_button);
+	play_button=clutter_texture_new_from_file("/opt/jammo/buttons/stop-button.png", NULL);
+	g_object_set(play_button, "x", 0.0,  "y", 195.0, NULL);
+	clutter_container_add(CLUTTER_CONTAINER(view), play_button, NULL);
+	clutter_actor_set_reactive(play_button,TRUE);
+	g_signal_connect (play_button, "button-press-event", G_CALLBACK (on_stop_button_clicked),NULL);
+
+	return FALSE;
+}
+
+
+
+gboolean themeselection_load(gchar* inputFilename) {
 	printf("Load button pressed\n");
 	JammoTrackView* track_view = bottom_track_view;
 	FILE *ifp;
-	gchar *inputFilename;
 
-	//filenames look like this: jammo_comp_2010.02.22_21.16.27.wav TODO
-	#ifdef N900
-	inputFilename = g_strdup_printf("/home/user/MyDocs/jammo_comp.wav");
-	#else
-	inputFilename = g_strdup_printf("/tmp/jammo/jammo_comp");
-	#endif
 	ifp = fopen(inputFilename, "r");
 	g_return_val_if_fail(ifp != NULL, FALSE);
 
@@ -489,4 +582,4 @@ Selected theme is 'name'-property of clicked button.
 void themeselection_theme_clicked(TangleAction *action, GObject *source, const gchar *trigger, TangleProperties *properties){
 	const gchar* name = clutter_actor_get_name(CLUTTER_ACTOR(source));
 	themeselection_start_theme(name);
-}
\ No newline at end of file
+}
